(setq comp-deferred-compilation t) ;; enable automatic native-compilation
(setq straight-repository-branch "develop")
(setq straight-vc-git-default-protocol 'ssh)
(setq straight--wait-for-async-jobs nil)

(eval-and-compile
  (defvar bootstrap-version)
  (let ((bootstrap-file
	 (expand-file-name "straight/repos/straight.el/bootstrap.el" user-emacs-directory))
	(bootstrap-version 5))
    (unless (file-exists-p bootstrap-file)
      (with-current-buffer
	  (url-retrieve-synchronously
	   "https://raw.githubusercontent.com/raxod502/straight.el/develop/install.el"
	   'silent 'inhibit-cookies)
	(goto-char (point-max))
	(eval-print-last-sexp)))
    (load bootstrap-file nil 'nomessage)))

(setq load-prefer-newer t)

(eval-and-compile (straight-use-package 'use-package))

    (defun org-git-version ()
      "The Git version of org-mode.
Inserted by installing org-mode or when a release is made."
      (let ((default-directory (straight--repos-dir "org")))
        (string-trim
         (with-output-to-string
           (with-current-buffer standard-output
             (call-process
              "git" nil t nil
              "describe"
              "--match=release*"
              "--abbrev=6"
              "HEAD"))))))

    (defun org-release ()
      "The release version of org-mode.
Inserted by installing org-mode or when a release is made."
      (let ((default-directory (straight--repos-dir "org")))
        (string-trim
         (string-remove-prefix
          "release_"
          (with-output-to-string
            (with-current-buffer standard-output
              (call-process
               "git" nil t nil
               "describe"
               "--match=release*"
               "--abbrev=0"
               "HEAD")))))))

(defun org-version (&optional here full message)
  "Show the Org version.
Interactively, or when MESSAGE is non-nil, show it in echo area.
With prefix argument, or when HERE is non-nil, insert it at point.
In non-interactive uses, a reduced version string is output unless
FULL is given."
  (interactive (list current-prefix-arg t (not current-prefix-arg)))
  (let ((org-dir (ignore-errors (org-find-library-dir "org")))
	(save-load-suffixes (when (boundp 'load-suffixes) load-suffixes))
	(load-suffixes (list ".el"))
	(org-install-dir
	 (ignore-errors (org-find-library-dir "org-loaddefs"))))
    (unless (and (fboundp 'org-release) (fboundp 'org-git-version))
      (org-load-noerror-mustsuffix (concat org-dir "org-version")))
    (let* ((load-suffixes save-load-suffixes)
	   (release (org-release))
	   (git-version (org-git-version))
	   (version (format "Org mode version %s (%s @ %s)"
			    release
			    git-version
			    (if org-install-dir
				(if (string= org-dir org-install-dir)
				    org-install-dir
				  (concat "mixed installation! "
					  org-install-dir
					  " and "
					  org-dir))
			      "org-loaddefs.el can not be found!")))
	   (version1 (if full version release)))
      (when here (insert version1))

(straight-use-package '(org
			:type git :repo "https://code.orgmode.org/bzg/org-mode.git"
                        :local-repo "org"
			:files (:defaults "contrib/lisp/*.el")
			:fork (:repo "/home/yantar92/Git/org-mode/" :branch "feature/drawertextprop")))

(use-package elfeed
  :straight t)

(use-package elfeed-org
  :straight t
  :config
  (elfeed-org))

;; when this file is loaded after org is native-compiled, the following error appears.
;; Error (use-package): elfeed-org/:catch: Invalid version syntax: ‘N/A’ (must start with a number)
;; deleting org.eln makes the error disappears

;; possible cause: straight--fix-org-function from straight.el is redefining some org.el functions
;; (org-git-version and org-release). This override fails to work in native-compiled org
